==> ceph-client-2024.2.194+6b985e51b.tgz: ceph-client/CHANGELOG.md <==
# Release notes

## 2024.2.0-40

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 fix the logic to disable the autoscaler on pools
- 0.1.3 Run as ceph user and disallow privilege escalation
- 0.1.4 Improvements for ceph-client helm tests
- 0.1.5 Fix Helm test check_pgs() check for inactive PGs
- 0.1.6 Uplift from Nautilus to Octopus release
- 0.1.7 Don't wait for premerge PGs in the rbd pool job
- 0.1.8 enhance logic to enable the autoscaler for Octopus
- 0.1.9 Revert "[ceph-client] enhance logic to enable the autoscaler for Octopus"
- 0.1.10 Separate pool quotas from pg_num calculations
- 0.1.11 enhance logic to enable and disable the autoscaler
- 0.1.12 Disable autoscaling before pools are created
- 0.1.13 Fix ceph-client helm test
- 0.1.14 Allow Ceph RBD pool job to leave failed pods
- 0.1.15 Make ceph-client helm test more PG specific
- 0.1.16 Make Ceph pool init job consistent with helm test
- 0.1.17 Add pool rename support for Ceph pools
- 0.1.18 Add pool delete support for Ceph pools
- 0.1.19 Use full image ref for docker official images
- 0.1.20 Export crash dumps when Ceph daemons crash
- 0.1.21 Fix Ceph checkDNS script
- 0.1.22 Set pg_num_min in all cases
- 0.1.23 Helm 3 - Fix Job labels
- 0.1.24 Performance optimizations for the ceph-rbd-pool job
- 0.1.25 Update htk requirements
- 0.1.26 Fix ceph-rbd-pool deletion race
- 0.1.27 Update ceph_mon config to ips from fqdn
- 0.1.28 Fix ceph.conf update job labels, rendering
- 0.1.29 Consolidate mon_host discovery
- 0.1.30 Move ceph-mgr deployment to the ceph-mon chart
- 0.1.31 Consolidate mon_endpoints discovery
- 0.1.32 Simplify test rules for ceph-mgr deployment
- 0.1.33 More robust naming of clusterrole-checkdns
- 0.1.34 Migrated CronJob resource to batch/v1 API version
- 0.1.35 Handle multiple mon versions in the pool job
- 0.1.36 Add the ability to run Ceph commands from values
- 0.1.37 Added OCI registry authentication
- 0.1.38 Make use of noautoscale with Pacific
- 0.1.39 Correct check for too many OSDs in the pool job
- 0.1.40 Fix OSD count checks in the ceph-rbd-pool job
- 0.1.41 Allow gate scripts to use 1x replication in Ceph
- 0.1.42 Update all Ceph images to Focal
- 0 1.43 Document the use of mon_allow_pool_size_one
- 0.1.44 Allow pg_num_min to be overridden per pool
- 0.1.45 Update Ceph to 17.2.6
- 0.1.46 Strip any errors preceding pool properties JSON
- 0.1.47 Use Helm toolkit functions for Ceph probes
- 0.1.48 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.1.49 Update Ceph images to Jammy and Reef 18.2.1
- 0.1.50 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.1.51 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.52 Run utils-defragOSDs.sh in ceph-osd-default container
- 0.1.53 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

==> ceph-client-2025.1.1+35052e51b.tgz: ceph-client/CHANGELOG.md <==
# Release notes

## 2025.1.0-83

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 fix the logic to disable the autoscaler on pools
- 0.1.3 Run as ceph user and disallow privilege escalation
- 0.1.4 Improvements for ceph-client helm tests
- 0.1.5 Fix Helm test check_pgs() check for inactive PGs
- 0.1.6 Uplift from Nautilus to Octopus release
- 0.1.7 Don't wait for premerge PGs in the rbd pool job
- 0.1.8 enhance logic to enable the autoscaler for Octopus
- 0.1.9 Revert "[ceph-client] enhance logic to enable the autoscaler for Octopus"
- 0.1.10 Separate pool quotas from pg_num calculations
- 0.1.11 enhance logic to enable and disable the autoscaler
- 0.1.12 Disable autoscaling before pools are created
- 0.1.13 Fix ceph-client helm test
- 0.1.14 Allow Ceph RBD pool job to leave failed pods
- 0.1.15 Make ceph-client helm test more PG specific
- 0.1.16 Make Ceph pool init job consistent with helm test
- 0.1.17 Add pool rename support for Ceph pools
- 0.1.18 Add pool delete support for Ceph pools
- 0.1.19 Use full image ref for docker official images
- 0.1.20 Export crash dumps when Ceph daemons crash
- 0.1.21 Fix Ceph checkDNS script
- 0.1.22 Set pg_num_min in all cases
- 0.1.23 Helm 3 - Fix Job labels
- 0.1.24 Performance optimizations for the ceph-rbd-pool job
- 0.1.25 Update htk requirements
- 0.1.26 Fix ceph-rbd-pool deletion race
- 0.1.27 Update ceph_mon config to ips from fqdn
- 0.1.28 Fix ceph.conf update job labels, rendering
- 0.1.29 Consolidate mon_host discovery
- 0.1.30 Move ceph-mgr deployment to the ceph-mon chart
- 0.1.31 Consolidate mon_endpoints discovery
- 0.1.32 Simplify test rules for ceph-mgr deployment
- 0.1.33 More robust naming of clusterrole-checkdns
- 0.1.34 Migrated CronJob resource to batch/v1 API version
- 0.1.35 Handle multiple mon versions in the pool job
- 0.1.36 Add the ability to run Ceph commands from values
- 0.1.37 Added OCI registry authentication
- 0.1.38 Make use of noautoscale with Pacific
- 0.1.39 Correct check for too many OSDs in the pool job
- 0.1.40 Fix OSD count checks in the ceph-rbd-pool job
- 0.1.41 Allow gate scripts to use 1x replication in Ceph
- 0.1.42 Update all Ceph images to Focal
- 0 1.43 Document the use of mon_allow_pool_size_one
- 0.1.44 Allow pg_num_min to be overridden per pool
- 0.1.45 Update Ceph to 17.2.6
- 0.1.46 Strip any errors preceding pool properties JSON
- 0.1.47 Use Helm toolkit functions for Ceph probes
- 0.1.48 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.1.49 Update Ceph images to Jammy and Reef 18.2.1
- 0.1.50 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.1.51 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.52 Run utils-defragOSDs.sh in ceph-osd-default container
- 0.1.53 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.
